aboutsummaryrefslogtreecommitdiffstats
path: root/mail/mail-send-recv.c
diff options
context:
space:
mode:
Diffstat (limited to 'mail/mail-send-recv.c')
-rw-r--r--mail/mail-send-recv.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/mail/mail-send-recv.c b/mail/mail-send-recv.c
index e70eade3e5..d47d69d278 100644
--- a/mail/mail-send-recv.c
+++ b/mail/mail-send-recv.c
@@ -277,8 +277,8 @@ static struct _send_data *build_dialogue(GSList *sources, CamelFolder *outbox, c
info = g_hash_table_lookup(data->active, source->url);
if (info == NULL) {
info = g_malloc0(sizeof(*info));
- /* imap is handled differently */
- if (!strncmp(source->url, "imap:", 5))
+ /* imap and spool are handled differently */
+ if (!strncmp(source->url, "imap:", 5) || !strncmp (source->url, "spool:", 6))
info->type = SEND_UPDATE;
else
info->type = SEND_RECEIVE;